
.. _datadb_face_inversion_demo:

*********************************
Eye-tracking Data: Face inversion
*********************************

TODO

Terms Of Use
============

TODO

Download
========

A tarball is available at:

  http://data.pymvpa.org/datasets/face_inversion_demo


Tarball Content
===============

TODO

References
==========

TODO
